@@ -24,6 +24,7 @@
 
 #include "cfg/config.h"
 #include "compat/reallocarray.h"
+#include "ui/tabs.h"
 #include "ui/ui.h"
 #include "utils/dynarray.h"
 #include "utils/matcher.h"
@@ -95,14 +96,22 @@ dot_filter_set(view_t *view, int visible)
 	{
 		load_dot_filter_option(view);
 	}
+
 	if(curr_stats.global_local_settings)
 	{
-		view_t *other = (view == curr_view) ? other_view : curr_view;
-		other->hide_dot_g = other->hide_dot = !visible;
-		ui_view_schedule_reload(other);
-		if(other == curr_view)
+		int i;
+		tab_info_t tab_info;
+		for(i = 0; tabs_enum_all(i, &tab_info); ++i)
 		{
-			load_dot_filter_option(other);
+			if(tab_info.view != view)
+			{
+				tab_info.view->hide_dot_g = tab_info.view->hide_dot = !visible;
+				ui_view_schedule_reload(tab_info.view);
+				if(tab_info.view == curr_view)
+				{
+					load_dot_filter_option(tab_info.view);
+				}
+			}
 		}
 	}
 }
@@ -116,30 +125,38 @@ dot_filter_toggle(view_t *view)
 	{
 		load_dot_filter_option(view);
 	}
+
 	if(curr_stats.global_local_settings)
 	{
-		view_t *other = (view == curr_view) ? other_view : curr_view;
-		other->hide_dot_g = other->hide_dot = !other->hide_dot;
-		ui_view_schedule_reload(other);
-		if(other == curr_view)
+		int i;
+		tab_info_t tab_info;
+		for(i = 0; tabs_enum_all(i, &tab_info); ++i)
 		{
-			load_dot_filter_option(other);
+			if(tab_info.view != view)
+			{
+				tab_info.view->hide_dot = !tab_info.view->hide_dot;
+				tab_info.view->hide_dot_g = tab_info.view->hide_dot;
+				ui_view_schedule_reload(tab_info.view);
+				if(tab_info.view == curr_view)
+				{
+					load_dot_filter_option(tab_info.view);
+				}
+			}
 		}
 	}
 }
 
 void
-name_filters_add_selection(view_t *view)
+name_filters_add_active(view_t *view)
 {
-	dir_entry_t *entry;
 	filter_t filter;
-	int filtered;
-
 	(void)filter_init(&filter, FILTER_DEF_CASE_SENSITIVITY);
 
+	flist_set_marking(view, 0);
+
 	/* Traverse items and update/create filter values. */
-	entry = NULL;
-	while(iter_selection_or_current(view, &entry))
+	dir_entry_t *entry = NULL;
+	while(iter_marked_entries(view, &entry))
 	{
 		const char *name = entry->name;
 		char name_with_slash[NAME_MAX + 1 + 1];
@@ -172,7 +189,7 @@ name_filters_add_selection(view_t *view)
 
 	/* Update entry lists to remove entries that must be filtered out now.  No
 	 * view reload is needed. */
-	filtered = zap_entries(view, view->dir_entry, &view->list_rows,
+	int filtered = zap_entries(view, view->dir_entry, &view->list_rows,
 			&is_newly_filtered, &filter, 0, 1);
 	if(flist_custom_active(view))
 	{
@@ -774,7 +791,8 @@ local_filter_apply(view_t *view, const char filter[])
 		return;
 	}
 
-	(void)filter_set(&view->local_filter.filter, filter);
+	int case_sensitive = !regexp_should_ignore_case(filter);
+	(void)filter_change(&view->local_filter.filter, filter, case_sensitive);
 	hists_filter_save(view->local_filter.filter.raw);
 
 	if(flist_custom_active(view) && view->custom.type != CV_TREE &&
