@@ -7,6 +7,8 @@
 #include <stdlib.h> /* free() */
 #include <string.h> /* memset() */
 
+#include <test-utils.h>
+
 #include "../../src/cfg/config.h"
 #include "../../src/cfg/info.h"
 #include "../../src/cfg/info_chars.h"
@@ -30,8 +32,6 @@
 #include "../../src/running.h"
 #include "../../src/sort.h"
 
-#include "utils.h"
-
 static void column_line_print(const void *data, int column_id, const char buf[],
 		size_t offset, AlignType align, const char full_column[]);
 static void setup_custom_view(view_t *view, int very);
@@ -308,7 +308,7 @@ TEST(unsorted_view_remains_one_on_vifminfo_reread_on_restart)
 	/* ls-like view blocks view column updates. */
 	copy_str(cfg.config_dir, sizeof(cfg.config_dir), SANDBOX_PATH);
 	curr_stats.restart_in_progress = 1;
-	read_info_file(1);
+	state_load(1);
 	curr_stats.restart_in_progress = 0;
 
 	assert_true(lwin.custom.type == CV_VERY);
@@ -335,7 +335,7 @@ TEST(location_is_saved_on_entering_custom_view)
 	copy_str(lwin.curr_dir, sizeof(lwin.curr_dir), cwd);
 
 	/* Put specific history entry and make sure it's used. */
-	flist_hist_save(&lwin, lwin.curr_dir, "b", 1);
+	flist_hist_setup(&lwin, lwin.curr_dir, "b", 1, 1);
 	load_dir_list(&lwin, 0);
 	assert_string_equal(lwin.curr_dir, cwd);
 	assert_string_equal("b", lwin.dir_entry[lwin.list_pos].name);
@@ -351,7 +351,7 @@ TEST(location_is_saved_on_entering_custom_view)
 	curr_stats.load_stage = 0;
 
 	/* Return to previous directory and check that last location was used. */
-	cd_updir(&lwin, 1);
+	rn_leave(&lwin, 1);
 	assert_string_equal("c", lwin.dir_entry[lwin.list_pos].name);
 
 	cfg_resize_histories(0U);
@@ -458,7 +458,7 @@ TEST(files_with_newline_in_names, IF(filenames_can_include_newline))
 
 	create_file("a\nb");
 	assert_non_null(get_cwd(lwin.curr_dir, sizeof(lwin.curr_dir)));
-	assert_success(output_to_custom_flist(&lwin, "cat list", 0, 0));
+	assert_success(rn_for_flist(&lwin, "cat list", "title", 0, 0));
 	assert_success(unlink("a\nb"));
 	assert_success(unlink("list"));
 
@@ -487,7 +487,7 @@ TEST(current_directory_can_be_added_via_dot)
 #endif
 	stats_update_shell_type(cfg.shell);
 
-	assert_success(output_to_custom_flist(&lwin, "echo ../misc", 0, 0));
+	assert_success(rn_for_flist(&lwin, "echo ../misc", "title", 0, 0));
 
 	stats_update_shell_type("/bin/sh");
 	update_string(&cfg.shell, NULL);
@@ -612,6 +612,7 @@ TEST(excluded_entries_do_not_return)
 	assert_int_equal(2, lwin.list_rows);
 
 	flist_custom_exclude(&lwin, 0);
+	assert_int_equal(0, lwin.selected_files);
 	assert_int_equal(1, lwin.list_rows);
 
 	load_dir_list(&lwin, 1);
@@ -639,6 +640,7 @@ TEST(excluding_entries_does_not_affect_local_filter_list)
 	assert_int_equal(2, lwin.list_rows);
 
 	flist_custom_exclude(&lwin, 0);
+	assert_int_equal(0, lwin.selected_files);
 	assert_int_equal(1, lwin.list_rows);
 
 	local_filter_remove(&lwin);
